Installation
------------

Dependencies
^^^^^^^^^^^^

scikit-learn-extra requires,

- Python (>=3.7)
- scikit-learn (>=0.24), and its dependencies


User installation
^^^^^^^^^^^^^^^^^

Latest release can be installed with conda,

.. code::

   conda install -c conda-forge scikit-learn-extra

or from PyPi with,

.. code::

   pip install scikit-learn-extra

Latest development version can be installed with,

.. code::

    pip install https://github.com/scikit-learn-contrib/scikit-learn-extra/archive/master.zip
